@@ -84,55 +84,55 @@ Creating tmp file.</source>
     </message>
     <message>
         <source>You don&apos;t remember this card yet.</source>
-        <translation>你還不記得這張卡片。</translation>
+        <translation type="unfinished">你還不記得這張卡片。</translation>
     </message>
     <message>
         <source>Like &apos;0&apos;, but it&apos;s getting more familiar.</source>
-        <translation>類似于‘0’，但它正變得更熟悉。</translation>
+        <translation type="unfinished">類似于‘0’，但它正變得更熟悉。</translation>
     </message>
     <message>
         <source> Show it less often.</source>
-        <translation>更少地察看它。</translation>
+        <translation type="unfinished">更少地察看它。</translation>
     </message>
     <message>
         <source>You&apos;ve memorised this card now,</source>
-        <translation>現在你記下了這張卡片，</translation>
+        <translation type="unfinished">現在你記下了這張卡片，</translation>
     </message>
     <message>
         <source> and will probably remember it for a few days.</source>
-        <translation>并可能記住几天。</translation>
+        <translation type="unfinished">并可能記住几天。</translation>
     </message>
     <message>
         <source>You have forgotten this card completely.</source>
-        <translation>你完全忘記了這張卡片。</translation>
+        <translation type="unfinished">你完全忘記了這張卡片。</translation>
     </message>
     <message>
         <source>Barely correct answer. The interval was way too long.</source>
-        <translation>勉強正確的答案。間隔的時間實在太長了。</translation>
+        <translation type="unfinished">勉強正確的答案。間隔的時間實在太長了。</translation>
     </message>
     <message>
         <source>Correct answer, but with much effort.</source>
-        <translation>正確的答案，但非常費勁。</translation>
+        <translation type="unfinished">正確的答案，但非常費勁。</translation>
     </message>
     <message>
         <source> The interval was probably too long.</source>
-        <translation>間隔的時間可能太長了。</translation>
+        <translation type="unfinished">間隔的時間可能太長了。</translation>
     </message>
     <message>
         <source>Correct answer, with some effort.</source>
-        <translation>正確的答案，需要稍作努力。</translation>
+        <translation type="unfinished">正確的答案，需要稍作努力。</translation>
     </message>
     <message>
         <source> The interval was probably just right.</source>
-        <translation>間隔的時間可能正好。</translation>
+        <translation type="unfinished">間隔的時間可能正好。</translation>
     </message>
     <message>
         <source>Correct answer, but without any</source>
-        <translation>正確的答案，但沒有任何</translation>
+        <translation type="unfinished">正確的答案，但沒有任何</translation>
     </message>
     <message>
         <source> difficulties. The interval was probably too short.</source>
-        <translation>困難。間隔的時間可能太短了。</translation>
+        <translation type="unfinished">困難。間隔的時間可能太短了。</translation>
     </message>
 </context>
 <context>
@@ -506,7 +506,7 @@ Creating tmp file.</source>
     </message>
     <message>
         <source>Number of grade 0 cards to learn at once:</source>
-        <translation>一次學習0分卡片數量：</translation>
+        <translation type="obsolete">一次學習0分卡片數量：</translation>
     </message>
     <message>
         <source>Note: this is NOT the number of grade 0 cards you want to memorise *per day*</source>
@@ -528,6 +528,10 @@ Creating tmp file.</source>
         <source>Learn new cards in random order</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Number of grade 0 cards to hold in your hand:</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>EditItemFrm</name>
@@ -867,63 +871,63 @@ so you might want to run </source>
     <name>MainDlg</name>
     <message>
         <source>Mnemosyne databases (*.mem)</source>
-        <translation>Mnemosyne 資料程式庫 (*.mem)</translation>
+        <translation type="unfinished">Mnemosyne 資料程式庫 (*.mem)</translation>
     </message>
     <message>
         <source>New</source>
-        <translation>新建</translation>
+        <translation type="unfinished">新建</translation>
     </message>
     <message>
         <source>Please wait...</source>
-        <translation>請稍候...</translation>
+        <translation type="unfinished">請稍候...</translation>
     </message>
     <message>
         <source>Mnemosyne</source>
-        <translation>Mnemosyne</translation>
+        <translation type="unfinished">Mnemosyne</translation>
     </message>
     <message>
         <source>Delete current card?</source>
-        <translation>移除目前卡片？</translation>
+        <translation type="unfinished">移除目前卡片？</translation>
     </message>
     <message>
         <source>&amp;Yes</source>
-        <translation>是(&amp;Y)</translation>
+        <translation type="unfinished">是(&amp;Y)</translation>
     </message>
     <message>
         <source>&amp;No</source>
-        <translation>否(&amp;N)</translation>
+        <translation type="unfinished">否(&amp;N)</translation>
     </message>
     <message>
         <source>Returns in </source>
-        <translation>在</translation>
+        <translation type="unfinished">在</translation>
     </message>
     <message>
         <source> day(s).</source>
-        <translation>天后傳回。</translation>
+        <translation type="unfinished">天后傳回。</translation>
     </message>
     <message>
         <source>Next repetition: today.</source>
-        <translation>下次重複：今天。</translation>
+        <translation type="unfinished">下次重複：今天。</translation>
     </message>
     <message>
         <source>Next repetition: tomorrow.</source>
-        <translation>下次重複：明天。</translation>
+        <translation type="unfinished">下次重複：明天。</translation>
     </message>
     <message>
         <source>Next repetition in </source>
-        <translation>下次重複在</translation>
+        <translation type="unfinished">下次重複在</translation>
     </message>
     <message>
         <source> days.</source>
-        <translation>天后。</translation>
+        <translation type="unfinished">天后。</translation>
     </message>
     <message>
         <source>Question:</source>
-        <translation>問題：</translation>
+        <translation type="unfinished">問題：</translation>
     </message>
     <message>
         <source>&lt;default&gt;</source>
-        <translation>&lt;預設&gt;</translation>
+        <translation type="unfinished">&lt;預設&gt;</translation>
     </message>
     <message>
         <source>Show &amp;answer</source>
@@ -931,27 +935,27 @@ so you might want to run </source>
     </message>
     <message>
         <source>Learn ahead of schedule</source>
-        <translation>提前學習</translation>
+        <translation type="unfinished">提前學習</translation>
     </message>
     <message>
         <source>Pick days until next repetition:</source>
-        <translation>選取直到下次重複的天數：</translation>
+        <translation type="unfinished">選取直到下次重複的天數：</translation>
     </message>
     <message>
         <source>Grade your answer:</source>
-        <translation>給你的答案評分：</translation>
+        <translation type="unfinished">給你的答案評分：</translation>
     </message>
     <message>
         <source>Scheduled: </source>
-        <translation>計划：</translation>
+        <translation type="unfinished">計划：</translation>
     </message>
     <message>
         <source>Not memorised: </source>
-        <translation>未記：</translation>
+        <translation type="unfinished">未記：</translation>
     </message>
     <message>
         <source>All: </source>
-        <translation>所有：</translation>
+        <translation type="unfinished">所有：</translation>
     </message>
     <message>
         <source>Show answer</source>
@@ -1419,7 +1423,7 @@ Happy learning!</source>
         <source>Scheduled cards for the next days:
 
 </source>
-        <translation>今后几天計划的卡片數：
+        <translation type="obsolete">今后几天計划的卡片數：
 
 </translation>
     </message>
@@ -1471,6 +1475,12 @@ Happy learning!</source>
         <source>Days until next repetition:</source>
         <translation type="unfinished">直到下次重複的天數：</translation>
     </message>
+    <message>
+        <source>Scheduled cards for next week:
+
+</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>StatisticsFrm</name>
